@@ -1,4 +1,3 @@
-#' @importFrom stats qchisq
 #' @rdname confint
 #' @srrstats {RE4.3} `confint()` method is exported.
 setMethod("confint", "EL", function(object,
@@ -6,13 +5,17 @@ setMethod("confint", "EL", function(object,
                                     level = 0.95,
                                     cv = NULL,
                                     control = el_control()) {
-  stopifnot("Invalid `control` specified." = (is(control, "ControlEL")))
   # No confidence interval for an empty model
   if (getNumPar(object) == 0L) {
-    ci <- matrix(, nrow = 0L, ncol = 2L)
+    ci <- matrix(numeric(0), nrow = 0L, ncol = 2L)
     colnames(ci) <- c("lower", "upper")
     return(ci)
   }
+  stopifnot(
+    "`object` has no `data`. Fit the model with `keep_data == TRUE`." =
+      (isFALSE(is.null(getData(object)))),
+    "Invalid `control` specified." = (is(control, "ControlEL"))
+  )
   est <- coef(object)
   # Index for tracking the parameters
   idx <- seq(length(est))
@@ -47,7 +50,6 @@ setMethod("confint", "EL", function(object,
     colnames(ci) <- c("lower", "upper")
     return(ci)
   }
-
   method <- getMethodEL(object)
   maxit <- control@maxit
   maxit_l <- control@maxit_l
@@ -64,12 +66,83 @@ setMethod("confint", "EL", function(object,
     idx_na <- which(is.na(idx))
     ci <- matrix(NA_real_, nrow = p, ncol = 2L)
     ci[-idx_na, ] <- compute_confidence_intervals(
-      method, est, getDataMatrix(object), cv, idx[-idx_na], maxit, maxit_l,
-      tol, tol_l, step, th, nthreads, w
+      method, est, getData(object), cv, idx[-idx_na], maxit, maxit_l, tol,
+      tol_l, step, th, nthreads, w
     )
   } else {
     ci <- compute_confidence_intervals(
-      method, est, getDataMatrix(object), cv, idx, maxit,
+      method, est, getData(object), cv, idx, maxit, maxit_l, tol, tol_l,
+      step, th, nthreads, w
+    )
+  }
+  dimnames(ci) <- list(pnames, c("lower", "upper"))
+  ci
+})
+
+#' @rdname confint
+setMethod("confint", "QGLM", function(object,
+                                      parm,
+                                      level = 0.95,
+                                      cv = NULL,
+                                      control = el_control()) {
+  if (getNumPar(object) == 1L) {
+    ci <- matrix(numeric(0), nrow = 0L, ncol = 2L)
+    colnames(ci) <- c("lower", "upper")
+    return(ci)
+  }
+  stopifnot(
+    "`object` has no `data`. Fit the model with `keep_data == TRUE`." =
+      (isFALSE(is.null(getData(object)))),
+    "Invalid `control` specified." = (is(control, "ControlEL"))
+  )
+  est <- coef(object)
+  idx <- seq(length(est))
+  pnames <- names(est)
+  if (!missing(parm)) {
+    if (is.numeric(parm) && all(is.finite(parm))) {
+      pnames <- pnames[parm]
+      idx <- match(pnames, names(est))
+    } else if (is.character(parm)) {
+      idx <- match(parm, pnames)
+      pnames <- parm
+    } else {
+      stop("Invalid `parm` specified.")
+    }
+  }
+  p <- length(idx)
+  level <- validate_level(level)
+  if (isTRUE(all.equal(level, 0))) {
+    ci <- matrix(rep(est[idx], 2L), ncol = 2L)
+    colnames(ci) <- c("lower", "upper")
+    return(ci)
+  } else if (isTRUE(all.equal(level, 1))) {
+    ci <- matrix(NA_real_, nrow = p, ncol = 2L)
+    ci[which(!is.na(idx)), ] <- c(-Inf, Inf)
+    colnames(ci) <- c("lower", "upper")
+    return(ci)
+  }
+  method <- getMethodEL(object)
+  maxit <- control@maxit
+  maxit_l <- control@maxit_l
+  tol <- control@tol
+  tol_l <- control@tol_l
+  step <- control@step
+  th <- control@th
+  nthreads <- control@nthreads
+  w <- getWeights(object)
+  cv <- if (is.null(cv)) qchisq(level, 1L) else validate_cv(cv, th)
+  if (all(is.na(idx))) {
+    ci <- matrix(NA_real_, nrow = p, ncol = 2L)
+  } else if (any(is.na(idx))) {
+    idx_na <- which(is.na(idx))
+    ci <- matrix(NA_real_, nrow = p, ncol = 2L)
+    ci[-idx_na, ] <- compute_confidence_intervals(
+      method, c(est, object@dispersion), getData(object), cv, idx[-idx_na],
+      maxit, maxit_l, tol, tol_l, step, th, nthreads, w
+    )
+  } else {
+    ci <- compute_confidence_intervals(
+      method, c(est, object@dispersion), getData(object), cv, idx, maxit,
       maxit_l, tol, tol_l, step, th, nthreads, w
     )
   }
@@ -77,14 +150,17 @@ setMethod("confint", "EL", function(object,
   ci
 })
 
-#' @importFrom stats qchisq
 #' @rdname confint
 setMethod("confint", "SD", function(object,
                                     parm,
                                     level = 0.95,
                                     cv = NULL,
                                     control = el_control()) {
-  stopifnot("Invalid `control` specified." = (is(control, "ControlEL")))
+  stopifnot(
+    "`object` has no `data`. Fit the model with `keep_data == TRUE`." =
+      (isFALSE(is.null(getData(object)))),
+    "Invalid `control` specified." = (is(control, "ControlEL"))
+  )
   est <- coef(object)
   idx <- seq(length(est))
   pnames <- if (is.null(names(est))) idx else names(est)
@@ -115,7 +191,6 @@ setMethod("confint", "SD", function(object,
     colnames(ci) <- c("lower", "upper")
     return(ci)
   }
-
   maxit <- control@maxit
   maxit_l <- control@maxit_l
   tol <- control@tol
@@ -131,13 +206,13 @@ setMethod("confint", "SD", function(object,
     idx_na <- which(is.na(idx))
     ci <- matrix(NA_real_, nrow = p, ncol = 2L)
     ci[-idx_na, ] <- compute_confidence_intervals(
-      "sd", est, getDataMatrix(object), cv, idx[-idx_na], maxit, maxit_l,
-      tol, tol_l, step, th, nthreads, w
+      "sd", est, getData(object), cv, idx[-idx_na], maxit, maxit_l, tol,
+      tol_l, step, th, nthreads, w
     )
   } else {
     ci <- compute_confidence_intervals(
-      "sd", est, getDataMatrix(object), cv, idx, maxit,
-      maxit_l, tol, tol_l, step, th, nthreads, w
+      "sd", est, getData(object), cv, idx, maxit, maxit_l, tol, tol_l,
+      step, th, nthreads, w
     )
   }
   dimnames(ci) <- list(pnames, c("lower", "upper"))
