@@ -17,22 +17,19 @@
 #'   `el_eval` does not return an object of class \linkS4class{EL}, and the
 #'   associated generics and methods are not applicable.
 #' @return A list with the following components:
-#'   \item{optim}{A list with the following optimization results:
-#'     \itemize{
-#'     \item{`lambda ` }{Lagrange multiplier of the dual problem.}
-#'     \item{`iterations ` }{Number of iterations performed.}
-#'     \item{`convergence ` }{Convergence status.}
-#'     }
-#'   }
-#'   \item{logp}{Log probabilities obtained from empirical likelihood.}
-#'   \item{logl}{Empirical log-likelihood.}
-#'   \item{loglr}{Empirical log-likelihood ratio.}
-#'   \item{statistic}{Minus twice the empirical log-likelihood ratio statistic
-#'   that has an asymptotic chi-square distribution.}
-#'   \item{df}{Degrees of freedom of the statistic.}
-#'   \item{pval}{\eqn{p}-value of the statistic.}
-#'   \item{npar}{Number of parameters.}
-#'   \item{weights}{Re-scaled weights used for model fitting.}
+#'   * `optim` A list with the following optimization results:
+#'     * `lambda` Lagrange multiplier of the dual problem.
+#'     * `iterations` Number of iterations performed.
+#'     * `convergence` Convergence status.
+#'   * `logp` Log probabilities obtained from empirical likelihood.
+#'   * `logl` Empirical log-likelihood.
+#'   * `loglr` Empirical log-likelihood ratio.
+#'   * `statistic` Minus twice the empirical log-likelihood ratio statistic
+#'   that has an asymptotic chi-square distribution.
+#'   * `df` Degrees of freedom of the statistic.
+#'   * `pval` \eqn{p}-value of the statistic.
+#'   * `npar` Number of parameters.
+#'   * `weights` Re-scaled weights used for model fitting.
 #' @references Qin J, Lawless J (1994).
 #'   “Empirical Likelihood and General Estimating Equations.”
 #'   The Annals of Statistics, 22(1), 300–325. \doi{10.1214/aos/1176325370}.
@@ -43,7 +40,6 @@
 #' par <- 0
 #' g <- x - par
 #' el_eval(g, weights = rep(c(1, 2), each = 25))
-#' @importFrom stats pchisq
 #' @export
 el_eval <- function(g, weights = NULL, control = el_control()) {
   mm <- as.matrix(g, rownames.force = TRUE)
@@ -62,7 +58,7 @@ el_eval <- function(g, weights = NULL, control = el_control()) {
   out <- compute_generic_EL(mm, control@maxit_l, control@tol_l, control@th, w)
   names(out$logp) <- nm
   out$df <- p
-  out$p.value <- pchisq(q = out$statistic, df = out$df, lower.tail = FALSE)
+  out$pval <- pchisq(q = out$statistic, df = out$df, lower.tail = FALSE)
   out$nobs <- n
   out$npar <- p
   out$weights <- w
