@@ -32,7 +32,6 @@ test_that("Probabilities add up to 1.", {
   x <- women$height
   w <- women$weight
   fit <- el_mean(x, par = 60)
-  expect_output(print(fit))
   expect_equal(sum(exp(fit@logp)), 1, tolerance = 1e-07)
   fit2 <- el_mean(x, par = 60, weights = w)
   expect_equal(sum(exp(fit2@logp)), 1, tolerance = 1e-07)
@@ -50,10 +49,10 @@ test_that("Conversion between `loglik` and `loglr`.", {
   x <- women$height
   n <- length(x)
   fit <- el_mean(x, par = 60)
-  expect_equal(fit@logl + n * log(n), logLR(fit))
+  expect_equal(logL(fit) + n * log(n), logLR(fit))
   fit2 <- el_mean(x, par = 60, weights = women$weight)
   w <- weights(fit2)
-  expect_equal(fit2@logl + sum(w * (log(n) - log(w))), logLR(fit2))
+  expect_equal(logL(fit2) + sum(w * (log(n) - log(w))), logLR(fit2))
 })
 
 test_that("`verbose` == TRUE in `el_control()`.", {
@@ -64,7 +63,9 @@ test_that("`verbose` == TRUE in `el_control()`.", {
 test_that("`conv()` methods.", {
   x <- women$height
   fit <- el_mean(x, par = 60)
+  fit2 <- el_mean(x, par = 0)
   expect_true(conv(fit))
+  expect_false(conv(fit2))
 })
 
 #' @srrstats {G5.7} Larger `tol_l` decreases the number of iterations for
@@ -73,7 +74,7 @@ test_that("Larger `tol_l` decreases iterations for convergence.", {
   x <- women$height
   fit <- el_mean(x, par = 60, control = el_control(tol_l = 1e-08))
   fit2 <- el_mean(x, par = 60, control = el_control(tol_l = 1e-02))
-  expect_gte(fit@optim$iterations, fit2@optim$iterations)
+  expect_gte(getOptim(fit)$iterations, getOptim(fit2)$iterations)
 })
 
 #' @srrstats {G5.9, G5.9a} Adding trivial noise does not change the overall
@@ -82,7 +83,7 @@ test_that("Noise susceptibility tests.", {
   x <- women$height
   fit <- el_mean(x, par = 60)
   fit2 <- el_mean(x, par = 60 + .Machine$double.eps)
-  expect_equal(fit@optim, fit2@optim)
+  expect_equal(getOptim(fit), getOptim(fit2))
 })
 
 #' @srrstats {RE1.4} Violation of the convex hull constraint is tested.
@@ -90,7 +91,16 @@ test_that("Convex hull constraint violated.", {
   x <- women$weight
   grid <- seq(10, 50, length.out = 1000)
   conv <- function(par) {
-    el_mean(x, par)@optim$convergence
+    getOptim(el_mean(x, par))$convergence
   }
   expect_false(any(vapply(grid, conv, FUN.VALUE = logical(1))))
 })
+
+test_that("`print()` method.", {
+  x <- women$height
+  fit <- el_mean(x, par = 60)
+  expect_output(show(fit))
+  expect_output(print(fit))
+  fit@statistic <- numeric()
+  expect_output(print(fit))
+})
